@@ -33,7 +33,7 @@
 #include <goffice/app/io-context.h>
 #include <command-context.h>
 #include <command-context-stderr.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <bonobo/bonobo-object.h>
 #include <bonobo/bonobo-main.h>
@@ -105,7 +105,7 @@ capp_class_init (CorbaApplicationClass *capp)
 	capp->epv.workbook_open	= capp_workbook_open;
 }
 
-static BONOBO_TYPE_FUNC_FULL (CorbaApplication, 
+static BONOBO_TYPE_FUNC_FULL (CorbaApplication,
 		       GNOME_Gnumeric_Application,
 		       BONOBO_OBJECT_TYPE,
 		       capp);
@@ -151,4 +151,3 @@ go_plugin_shutdown (GOPlugin *p, GOCmdContext *cc)
 }
 
 GNM_PLUGIN_MODULE_HEADER;
-
