@@ -233,7 +233,7 @@ static GnmValue *
 gnumeric_hypot (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	return float_range_function (argc, argv, ei,
-				     range_hypot,
+				     gnm_range_hypot,
 				     COLLECT_IGNORE_STRINGS |
 				     COLLECT_IGNORE_BOOLS |
 				     COLLECT_IGNORE_BLANKS,
@@ -1498,7 +1498,7 @@ static GnmValue *
 gnumeric_suma (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	return float_range_function (argc, argv, ei,
-				     range_sum,
+				     gnm_range_sum,
 				     COLLECT_ZERO_STRINGS |
 				     COLLECT_ZEROONE_BOOLS |
 				     COLLECT_IGNORE_BLANKS,
@@ -1532,7 +1532,7 @@ static GnmValue *
 gnumeric_sumsq (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	return float_range_function (argc, argv, ei,
-				     range_sumsq,
+				     gnm_range_sumsq,
 				     COLLECT_IGNORE_STRINGS |
 				     COLLECT_IGNORE_BOOLS |
 				     COLLECT_IGNORE_BLANKS,
@@ -1564,7 +1564,7 @@ static GnmValue *
 gnumeric_multinomial (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	return float_range_function (argc, argv, ei,
-				     range_multinomial,
+				     gnm_range_multinomial,
 				     COLLECT_IGNORE_STRINGS |
 				     COLLECT_IGNORE_BOOLS |
 				     COLLECT_IGNORE_BLANKS,
@@ -1595,7 +1595,7 @@ static GnmValue *
 gnumeric_g_product (GnmFuncEvalInfo *ei, int argc, GnmExprConstPtr const *argv)
 {
 	return float_range_function (argc, argv, ei,
-				     range_product,
+				     gnm_range_product,
 				     COLLECT_IGNORE_STRINGS |
 				     COLLECT_IGNORE_BOOLS |
 				     COLLECT_IGNORE_BLANKS,
@@ -2997,7 +2997,7 @@ free_matrix (gnm_float **mat, G_GNUC_UNUSED int cols, int rows)
 
 	for (r = 0; r < rows; r++)
 		g_free (mat[r]);
-		
+
 	g_free (mat);
 }
 
@@ -3022,7 +3022,7 @@ gnumeric_minverse (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 		return value_new_error_VALUE (ei->pos);
 
 	matrix = value_to_matrix (values, cols, rows, ep);
-	if (!matrix_invert (matrix, rows)) {
+	if (!gnm_matrix_invert (matrix, rows)) {
 		free_matrix (matrix, cols, rows);
 		return value_new_error_NUM (ei->pos);
 	}
@@ -3160,7 +3160,7 @@ gnumeric_mdeterm (GnmFuncEvalInfo *ei, GnmValue const * const *argv)
 		return value_new_error_VALUE (ei->pos);
 
 	matrix = value_to_matrix (values, cols, rows, ep);
-	res = matrix_determinant (matrix, rows);
+	res = gnm_matrix_determinant (matrix, rows);
 	free_matrix (matrix, cols, rows);
 
 	return value_new_float (res);
@@ -3330,11 +3330,11 @@ GnmFuncDescriptor const math_functions[] = {
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 
 	{ "ceil",    "f", N_("number"),    help_ceil,
-	  gnumeric_ceil, NULL, NULL, NULL, NULL,	  
+	  gnumeric_ceil, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "ceiling", "f|f", N_("number,significance"), help_ceiling,
-	  gnumeric_ceiling, NULL, NULL, NULL, NULL,	  
+	  gnumeric_ceiling, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "degrees", "f", N_("number"),    help_degrees,
@@ -3365,7 +3365,7 @@ GnmFuncDescriptor const math_functions[] = {
 	  gnumeric_combin, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "floor",   "f|f", N_("number"),  help_floor,
-	  gnumeric_floor, NULL, NULL, NULL, NULL,	  
+	  gnumeric_floor, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "gcd", NULL, N_("number,number"), help_gcd,
@@ -3375,7 +3375,7 @@ GnmFuncDescriptor const math_functions[] = {
 	  NULL, gnumeric_hypot, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_UNIQUE_TO_GNUMERIC, GNM_FUNC_TEST_STATUS_NO_TESTSUITE },
 	{ "int",     "f", N_("number"),    help_int,
-	  gnumeric_int, NULL, NULL, NULL, NULL,	  
+	  gnumeric_int, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "lcm", NULL, "",            help_lcm,
@@ -3400,7 +3400,7 @@ GnmFuncDescriptor const math_functions[] = {
 	  gnumeric_mod, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "mround",  "ff", N_("number,multiple"), help_mround,
-	  gnumeric_mround, NULL, NULL, NULL, NULL,	  
+	  gnumeric_mround, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "multinomial", NULL, "", help_multinomial,
@@ -3425,15 +3425,15 @@ GnmFuncDescriptor const math_functions[] = {
 	  gnumeric_roman, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "round",      "f|f", N_("number,digits"), help_round,
-	  gnumeric_round, NULL, NULL, NULL, NULL,	  
+	  gnumeric_round, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "rounddown",  "f|f", N_("number,digits"), help_rounddown,
-	  gnumeric_rounddown, NULL, NULL, NULL, NULL,	  
+	  gnumeric_rounddown, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "roundup",    "f|f", N_("number,digits"), help_roundup,
-	  gnumeric_roundup, NULL, NULL, NULL, NULL,	  
+	  gnumeric_roundup, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "seriessum", NULL, N_("x,n,m,coefficients"), help_seriessum,
@@ -3455,7 +3455,7 @@ GnmFuncDescriptor const math_functions[] = {
 	  gnumeric_sqrtpi, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "suma", NULL, N_("number,number,"), help_suma,
-	  NULL, gnumeric_suma, NULL, NULL, NULL,	  
+	  NULL, gnumeric_suma, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "sumif",   "rS|r", N_("range,criteria,actual_range"), help_sumif,
@@ -3483,7 +3483,7 @@ GnmFuncDescriptor const math_functions[] = {
 	  gnumeric_tanh, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE, GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_EXHAUSTIVE },
 	{ "trunc",   "f|f", N_("number,digits"), help_trunc,
-	  gnumeric_trunc, NULL, NULL, NULL, NULL,	  
+	  gnumeric_trunc, NULL, NULL, NULL, NULL,
 	  GNM_FUNC_SIMPLE + GNM_FUNC_AUTO_FIRST,
 	  GNM_FUNC_IMPL_STATUS_COMPLETE, GNM_FUNC_TEST_STATUS_BASIC },
 	{ "pi",      "", "",           help_pi,
