@@ -44,24 +44,12 @@
 
 #include <gui-util.h>
 #include <glade/glade.h>
-#include <gtk/gtktreeview.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtktreestore.h>
-#include <gtk/gtktreeselection.h>
-#include <gtk/gtkscrolledwindow.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtknotebook.h>
-#include <gtk/gtkimage.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtkstock.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtktogglebutton.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
+#define PREF_DIALOG_KEY "pref-dialog"
+
 enum {
 	ITEM_ICON,
 	ITEM_NAME,
@@ -72,12 +60,12 @@ enum {
 typedef struct {
 	GladeXML	*gui;
 	GtkWidget	*dialog;
-	GtkWidget	*notebook;
+	GtkNotebook	*notebook;
 	GtkTextView	*description;
 	GtkTreeStore    *store;
 	GtkTreeView     *view;
-	Workbook	*wb;
 	GOConfNode	*root;
+	gulong          app_wb_removed_sig;
 } PrefState;
 
 typedef void (* double_conf_setter_t) (gnm_float value);
@@ -912,7 +900,7 @@ dialog_pref_select_page (PrefState *state, char const *page)
 	GtkTreeIter iter;
 	GtkTreePath *path;
 
-	path = gtk_tree_path_new_from_string  (page);
+	path = gtk_tree_path_new_from_string (page);
 	
 	if (path != NULL) {
 		gtk_tree_selection_select_path (selection, path);
@@ -934,8 +922,7 @@ cb_dialog_pref_selection_changed (GtkTreeSelection *selection,
 		gtk_tree_model_get (GTK_TREE_MODEL (state->store), &iter,
 				    PAGE_NUMBER, &page,
 				    -1);
-		gtk_notebook_set_current_page (GTK_NOTEBOOK(state->notebook),
-					       page);
+		gtk_notebook_set_current_page (state->notebook, page);
 	} else {
 		dialog_pref_select_page (state, "0");
 	}
@@ -945,12 +932,20 @@ static void
 cb_preferences_destroy (PrefState *state)
 {
 	go_conf_sync (state->root);
-	if (state->store)
+	if (state->store) {
 		g_object_unref (state->store);
-	if (state->gui != NULL)
+		state->store = NULL;
+	}
+	if (state->gui != NULL) {
 		g_object_unref (G_OBJECT (state->gui));
-	g_free (state);
-	gnm_app_set_pref_dialog (NULL);
+		state->gui = NULL;
+	}
+	if (state->app_wb_removed_sig) {
+		g_signal_handler_disconnect (gnm_app_get_app (),
+					     state->app_wb_removed_sig);
+		state->app_wb_removed_sig = 0;
+	}
+	g_object_set_data (gnm_app_get_app (), PREF_DIALOG_KEY, NULL);
 }
 
 static void
@@ -971,6 +966,14 @@ cb_dialog_pref_switch_page  (GtkNotebook *notebook,
 		dialog_pref_page_open (state);
 }
 
+static void
+cb_workbook_removed (PrefState *state)
+{
+	if (gnm_app_workbook_list () == NULL)
+		cb_close_clicked (state);
+}
+
+
 /* Note: The first page listed below is opened through File/Preferences, */
 /*       and the second through Format/Workbook */
 static char const * const startup_pages[] = {"1", "0"};
@@ -985,7 +988,7 @@ dialog_preferences (WBCGtk *wbcg, gint page)
 	GtkTreeViewColumn *column;
 	GtkTreeSelection  *selection;
 
-	w = gnm_app_get_pref_dialog ();
+	w = g_object_get_data (gnm_app_get_app (), PREF_DIALOG_KEY);
 	if (w) {
 		gtk_widget_show (w);
 		gdk_window_raise (w->window);
@@ -1001,9 +1004,8 @@ dialog_preferences (WBCGtk *wbcg, gint page)
 	state->root = gnm_conf_get_root ();
 	state->gui = gui;
 	state->dialog     = glade_xml_get_widget (gui, "preferences");
-	state->notebook   = glade_xml_get_widget (gui, "notebook");
+	state->notebook = (GtkNotebook*)glade_xml_get_widget (gui, "notebook");
 	state->description = GTK_TEXT_VIEW (glade_xml_get_widget (gui, "description"));
-	state->wb	  = wb_control_get_workbook (WORKBOOK_CONTROL (wbcg));
 
 	state->view = GTK_TREE_VIEW(glade_xml_get_widget (gui, "itemlist"));
 	state->store = gtk_tree_store_new (NUM_COLUMNS,
@@ -1040,15 +1042,25 @@ dialog_preferences (WBCGtk *wbcg, gint page)
 	gnumeric_init_help_button (
 		glade_xml_get_widget (state->gui, "help_button"),
 		GNUMERIC_HELP_LINK_PREFERENCES);
+	g_signal_connect_swapped (G_OBJECT (state->dialog), "destroy",
+				  G_CALLBACK (cb_preferences_destroy),
+				  state);
 	g_object_set_data_full (G_OBJECT (state->dialog),
-		"state", state, (GDestroyNotify) cb_preferences_destroy);
+				"state", state,	(GDestroyNotify)g_free);
 
-	gnm_app_set_pref_dialog (state->dialog);
+	g_object_set_data (gnm_app_get_app (), PREF_DIALOG_KEY, state->dialog);
+
+	state->app_wb_removed_sig =
+		g_signal_connect_swapped (gnm_app_get_app (),
+					  "workbook_removed",
+					  G_CALLBACK (cb_workbook_removed),
+					  state);
 
 	for (i = 0; page_info[i].page_initializer; i++) {
 		const page_info_t *this_page =  &page_info[i];
-		GtkWidget *page = this_page->page_initializer (state, this_page->data,
-							       GTK_NOTEBOOK (state->notebook), i);
+		GtkWidget *page =
+			this_page->page_initializer (state, this_page->data,
+						     state->notebook, i);
 		GtkWidget *label = NULL;
 
 		if (this_page->icon_name)
@@ -1056,7 +1068,7 @@ dialog_preferences (WBCGtk *wbcg, gint page)
 							  GTK_ICON_SIZE_BUTTON);
 		else if (this_page->page_name)
 			label = gtk_label_new (this_page->page_name);
-		gtk_notebook_append_page (GTK_NOTEBOOK (state->notebook), page, label);
+		gtk_notebook_append_page (state->notebook, page, label);
 		dialog_pref_add_item (state, this_page->page_name, this_page->icon_name, i, this_page->parent_path);
 	}
 
