@@ -7,8 +7,8 @@
  *     Jody Goldberg (jody@gnome.org)
  *
  * Port to Maemo:
- * 	Eduardo Lima  (eduardo.lima@indt.org.br)
- * 	Renato Araujo (renato.filho@indt.org.br)
+ *	Eduardo Lima  (eduardo.lima@indt.org.br)
+ *	Renato Araujo (renato.filho@indt.org.br)
  */
 #include <gnumeric-config.h>
 #include <glib/gi18n-lib.h>
@@ -523,7 +523,7 @@ gnm_pane_colrow_key_press (SheetControlGUI *scg, GdkEventKey *event,
 		if (event->state & GDK_CONTROL_MASK)	/* full sheet */
 			/* TODO : How to handle ctrl-A too ? */
 			range_init_full_sheet (&target);
-		else {				 	/* full row */
+		else {					/* full row */
 			target.start.col = 0;
 			target.end.col = SHEET_MAX_COLS - 1;
 		}
@@ -627,7 +627,7 @@ gnm_pane_key_release (GtkWidget *widget, GdkEventKey *event)
 static gint
 gnm_pane_focus_in (GtkWidget *widget, GdkEventFocus *event)
 {
-#ifndef USE_HILDON
+#ifndef GNM_USE_HILDON
 	gtk_im_context_focus_in (GNM_PANE (widget)->im_context);
 #endif
 	return (*GTK_WIDGET_CLASS (parent_klass)->focus_in_event) (widget, event);
@@ -681,75 +681,6 @@ gnm_pane_size_allocate (GtkWidget *w, GtkAllocation *allocation)
 	gnm_pane_compute_visible_region (pane, TRUE);
 }
 
-static void
-gnm_pane_dispose (GObject *obj)
-{
-	GnmPane *pane = GNM_PANE (obj);
-
-	if (pane->col.canvas != NULL) {
-		gtk_object_destroy (GTK_OBJECT (pane->col.canvas));
-		pane->col.canvas = NULL;
-	}
-
-	if (pane->row.canvas != NULL) {
-		gtk_object_destroy (GTK_OBJECT (pane->row.canvas));
-		pane->row.canvas = NULL;
-	}
-	if (pane->cursor.animated != NULL) {
-		g_slist_free (pane->cursor.animated);
-		pane->cursor.animated = NULL;
-	}
-
-	if (pane->mouse_cursor) {
-		gdk_cursor_unref (pane->mouse_cursor);
-		pane->mouse_cursor = NULL;
-	}
-	gnm_pane_clear_obj_size_tip (pane);
-
-	if (pane->drag.ctrl_pts) {
-		g_hash_table_destroy (pane->drag.ctrl_pts);
-		pane->drag.ctrl_pts = NULL;
-	}
-
-	/* Be anal just in case we somehow manage to remove a pane
-	 * unexpectedly.  */
-	pane->grid = NULL;
-	pane->editor = NULL;
-	pane->cursor.std = pane->cursor.rangesel = pane->cursor.special = pane->cursor.expr_range = NULL;
-	pane->size_guide.guide = NULL;
-	pane->size_guide.start = NULL;
-	pane->size_guide.points = NULL;
-
-	G_OBJECT_CLASS (parent_klass)->dispose (obj);
-}
-
-static void
-gnm_pane_finalize (GObject *object)
-{
-	g_object_unref (G_OBJECT (GNM_PANE (object)->im_context));
-	G_OBJECT_CLASS (parent_klass)->finalize (object);
-}
-
-static void
-gnm_pane_class_init (GnmPaneClass *klass)
-{
-	GObjectClass   *gobject_class = G_OBJECT_CLASS (klass);
-	GtkWidgetClass *widget_class  = (GtkWidgetClass *) klass;
-
-	parent_klass = g_type_class_peek_parent (klass);
-
-	gobject_class->dispose  = gnm_pane_dispose;
-	gobject_class->finalize = gnm_pane_finalize;
-
-	widget_class->realize		   = gnm_pane_realize;
-	widget_class->unrealize		   = gnm_pane_unrealize;
-	widget_class->size_allocate	   = gnm_pane_size_allocate;
-	widget_class->key_press_event	   = gnm_pane_key_press;
-	widget_class->key_release_event	   = gnm_pane_key_release;
-	widget_class->focus_in_event	   = gnm_pane_focus_in;
-	widget_class->focus_out_event	   = gnm_pane_focus_out;
-}
-
 static GtkEditable *
 gnm_pane_get_editable (GnmPane const *pane)
 {
@@ -884,6 +815,63 @@ cb_ctrl_pts_free (GtkObject **ctrl_pts)
 	g_free (ctrl_pts);
 }
 
+static void
+gnm_pane_dispose (GObject *obj)
+{
+	GnmPane *pane = GNM_PANE (obj);
+
+	if (pane->col.canvas != NULL) {
+		gtk_object_destroy (GTK_OBJECT (pane->col.canvas));
+		pane->col.canvas = NULL;
+	}
+
+	if (pane->row.canvas != NULL) {
+		gtk_object_destroy (GTK_OBJECT (pane->row.canvas));
+		pane->row.canvas = NULL;
+	}
+
+	if (pane->im_context) {
+		GtkIMContext *imc = pane->im_context;
+
+		pane->im_context = NULL;
+		g_signal_handlers_disconnect_by_func
+			(imc, cb_gnm_pane_commit, pane);
+		g_signal_handlers_disconnect_by_func
+			(imc, cb_gnm_pane_preedit_changed, pane);
+		g_signal_handlers_disconnect_by_func
+			(imc, cb_gnm_pane_retrieve_surrounding, pane);
+		g_signal_handlers_disconnect_by_func
+			(imc, cb_gnm_pane_delete_surrounding, pane);
+		gtk_im_context_set_client_window (imc, NULL);
+		g_object_unref (imc);
+	}
+
+	g_slist_free (pane->cursor.animated);
+	pane->cursor.animated = NULL;
+
+	if (pane->mouse_cursor) {
+		gdk_cursor_unref (pane->mouse_cursor);
+		pane->mouse_cursor = NULL;
+	}
+	gnm_pane_clear_obj_size_tip (pane);
+
+	if (pane->drag.ctrl_pts) {
+		g_hash_table_destroy (pane->drag.ctrl_pts);
+		pane->drag.ctrl_pts = NULL;
+	}
+
+	/* Be anal just in case we somehow manage to remove a pane
+	 * unexpectedly.  */
+	pane->grid = NULL;
+	pane->editor = NULL;
+	pane->cursor.std = pane->cursor.rangesel = pane->cursor.special = pane->cursor.expr_range = NULL;
+	pane->size_guide.guide = NULL;
+	pane->size_guide.start = NULL;
+	pane->size_guide.points = NULL;
+
+	G_OBJECT_CLASS (parent_klass)->dispose (obj);
+}
+
 static void
 gnm_pane_init (GnmPane *pane)
 {
@@ -930,13 +918,34 @@ gnm_pane_init (GnmPane *pane)
 	GTK_WIDGET_SET_FLAGS (canvas, GTK_CAN_DEFAULT);
 
 	g_signal_connect (G_OBJECT (pane->im_context), "commit",
-		G_CALLBACK (cb_gnm_pane_commit), pane);
+			  G_CALLBACK (cb_gnm_pane_commit), pane);
 	g_signal_connect (G_OBJECT (pane->im_context), "preedit_changed",
-		G_CALLBACK (cb_gnm_pane_preedit_changed), pane);
+			  G_CALLBACK (cb_gnm_pane_preedit_changed), pane);
 	g_signal_connect (G_OBJECT (pane->im_context), "retrieve_surrounding",
-		G_CALLBACK (cb_gnm_pane_retrieve_surrounding), pane);
+			  G_CALLBACK (cb_gnm_pane_retrieve_surrounding),
+			  pane);
 	g_signal_connect (G_OBJECT (pane->im_context), "delete_surrounding",
-		G_CALLBACK (cb_gnm_pane_delete_surrounding), pane);
+			  G_CALLBACK (cb_gnm_pane_delete_surrounding),
+			  pane);
+}
+
+static void
+gnm_pane_class_init (GnmPaneClass *klass)
+{
+	GObjectClass   *gobject_class = G_OBJECT_CLASS (klass);
+	GtkWidgetClass *widget_class  = (GtkWidgetClass *) klass;
+
+	parent_klass = g_type_class_peek_parent (klass);
+
+	gobject_class->dispose  = gnm_pane_dispose;
+
+	widget_class->realize		   = gnm_pane_realize;
+	widget_class->unrealize		   = gnm_pane_unrealize;
+	widget_class->size_allocate	   = gnm_pane_size_allocate;
+	widget_class->key_press_event	   = gnm_pane_key_press;
+	widget_class->key_release_event	   = gnm_pane_key_release;
+	widget_class->focus_in_event	   = gnm_pane_focus_in;
+	widget_class->focus_out_event	   = gnm_pane_focus_out;
 }
 
 GSF_CLASS (GnmPane, gnm_pane,
@@ -1959,7 +1968,7 @@ gnm_pane_display_obj_size_tip (GnmPane *pane, SheetObject const *so)
 
 	g_return_if_fail (pane->size_tip != NULL);
 
-	sheet_object_anchor_cpy	(&anchor, sheet_object_get_anchor (so));
+	sheet_object_anchor_assign (&anchor, sheet_object_get_anchor (so));
 	scg_object_coords_to_anchor (scg, coords, &anchor);
 	sheet_object_anchor_to_pts (&anchor, scg_sheet (scg), pts);
 	msg = g_strdup_printf (_("%.1f x %.1f pts\n%d x %d pixels"),
@@ -2237,13 +2246,13 @@ void
 gnm_pane_expr_cursor_bound_set (GnmPane *pane, GnmRange const *r)
 {
 	if (NULL == pane->cursor.expr_range)
-		pane->cursor.expr_range = ITEM_CURSOR (foo_canvas_item_new (
+		pane->cursor.expr_range = (ItemCursor *)foo_canvas_item_new (
 			FOO_CANVAS_GROUP (FOO_CANVAS (pane)->root),
 			item_cursor_get_type (),
 			"SheetControlGUI",	pane->simple.scg,
 			"style",		ITEM_CURSOR_BLOCK,
 			"color",		"red",
-			NULL));
+			NULL);
 
 	item_cursor_bound_set (pane->cursor.expr_range, r);
 }
@@ -2288,36 +2297,36 @@ gnm_pane_objects_drag (GnmPane *pane, SheetObject *so,
 		       gdouble new_x, gdouble new_y, int drag_type,
 		       gboolean symmetric,gboolean snap_to_grid)
 {
- 	double dx, dy;
- 	dx = new_x - pane->drag.last_x;
- 	dy = new_y - pane->drag.last_y;
+	double dx, dy;
+	dx = new_x - pane->drag.last_x;
+	dy = new_y - pane->drag.last_y;
 	pane->drag.had_motion = TRUE;
 
- 	scg_objects_drag (pane->simple.scg, pane,
- 		so, &dx, &dy, drag_type, symmetric, snap_to_grid, TRUE);
+	scg_objects_drag (pane->simple.scg, pane,
+		so, &dx, &dy, drag_type, symmetric, snap_to_grid, TRUE);
 
- 	pane->drag.last_x += dx;
- 	pane->drag.last_y += dy;
+	pane->drag.last_x += dx;
+	pane->drag.last_y += dy;
 }
 
 #define CTRL_PT_SIZE		4
 #define CTRL_PT_OUTLINE		0
 /* space for 2 halves and a full */
-#define CTRL_PT_TOTAL_SIZE 	(CTRL_PT_SIZE*4 + CTRL_PT_OUTLINE*2)
+#define CTRL_PT_TOTAL_SIZE	(CTRL_PT_SIZE*4 + CTRL_PT_OUTLINE*2)
 
 /* new_x and new_y are in world coords */
 static void
 gnm_pane_object_move (GnmPane *pane, GObject *ctrl_pt,
 		      gdouble new_x, gdouble new_y,
- 		      gboolean symmetric,
- 		      gboolean snap_to_grid)
+		      gboolean symmetric,
+		      gboolean snap_to_grid)
 {
 	int const idx = GPOINTER_TO_INT (g_object_get_data (ctrl_pt, "index"));
 	SheetObject *so  = g_object_get_data (G_OBJECT (ctrl_pt), "so");
 
 	gnm_pane_objects_drag (pane, so, new_x, new_y, idx,
 			       symmetric, snap_to_grid);
- 	if (idx != 8)
+	if (idx != 8)
 		gnm_pane_display_obj_size_tip (pane, so);
 }
 
@@ -2578,7 +2587,7 @@ gnm_pane_drag_begin (GnmPane *pane, SheetObject *so, GdkEvent *event)
 			char *target_name = gdk_atom_name (pair->target);
 			g_print ("%s\n", target_name);
 			g_free (target_name);
- 		}
+		}
 	}
 #endif
 
@@ -2805,7 +2814,7 @@ set_acetate_coords (GnmPane *pane, SheetObject *so, FooCanvasItem **ctrl_pts,
 			ctrl_pts [9] = foo_canvas_item_new (pane->action_items,
 				FOO_TYPE_CANVAS_RECT,
 				"fill-color",		NULL,
-				"width-units",   	1.,
+				"width-units",		1.,
 				"outline-color",	"black",
 				"outline-stipple",	stipple,
 				NULL);
@@ -2992,12 +3001,17 @@ cb_sheet_object_widget_canvas_event (GtkWidget *widget, GdkEvent *event,
 static void
 cb_bounds_changed (SheetObject *so, FooCanvasItem *sov)
 {
-	double coords[4];
+	double coords[4], *cur;
 	SheetControlGUI *scg = GNM_SIMPLE_CANVAS (sov->canvas)->scg;
-	if (NULL != scg->selected_objects &&
-	    NULL != g_hash_table_lookup (scg->selected_objects, so))
-		return;
+
 	scg_object_anchor_to_coords (scg, sheet_object_get_anchor (so), coords);
+	if (NULL != scg->selected_objects &&
+	    NULL != (cur = g_hash_table_lookup (scg->selected_objects, so))) {
+		int i;
+		for (i = 4; i-- > 0 ;) cur[i] = coords[i];
+		gnm_pane_object_update_bbox (GNM_PANE (sov->canvas), so);
+	}
+
 	sheet_object_view_set_bounds (SHEET_OBJECT_VIEW (sov),
 		coords, so->flags & SHEET_OBJECT_IS_VISIBLE);
 }
