@@ -24,8 +24,10 @@
 #include "workbook-view.h"
 #include "gnumeric-gconf.h"
 #include "gnumeric-gconf-priv.h"
+#include "parse-util.h"
 
 #include <goffice/app/go-doc.h>
+#include <goffice/app/go-cmd-context.h>
 #include <goffice/utils/go-file.h>
 #include <goffice/utils/datetime.h>
 #include <goffice/utils/go-glib-extras.h>
@@ -35,6 +37,8 @@
 #include <locale.h>
 #include <time.h>
 
+#define PDF_SAVER_ID "Gnumeric_pdf:pdf_assistant"
+
 #define MAX_SAVED_CUSTOM_HF_FORMATS 9
 
 GList *hf_formats = NULL;
@@ -297,6 +301,7 @@ print_info_new (gboolean load_defaults)
 
 	res->start_page	   = -1;
 	res->n_copies	   = 0;
+	res->do_not_print   = FALSE;
 
 	res->page_setup = NULL;
 	res->page_breaks.v = NULL;
@@ -430,6 +435,52 @@ unit_to_unit_name (GtkUnit unit)
 }
 
 
+static void
+render_cell (GString *target, HFRenderInfo *info, char const *args)
+{
+	gboolean use_repeating = FALSE;
+
+	if (args && ((use_repeating = g_str_has_prefix (args, "rep|"))))
+		args += 4;
+
+	if (info->sheet) {
+		GnmRangeRef ref;
+		GnmValue const *val;
+		char const *tmp;
+		GnmParsePos ppos;
+
+		parse_pos_init (&ppos, info->sheet->workbook, (Sheet *)info->sheet, 0, 0);
+		tmp = rangeref_parse 
+			(&ref, args, &ppos, sheet_get_conventions (info->sheet));
+		if (tmp == NULL || tmp == args) {
+			gnm_cellref_init (&ref.a, (Sheet *)(info->sheet), 0, 0, FALSE);
+		}
+
+		if (ref.a.row_relative)
+			ref.a.row += (use_repeating ? 
+				      info->top_repeating.row : info->page_area.start.row);
+		if (ref.a.col_relative)
+			ref.a.col += (use_repeating ? 
+				      info->top_repeating.col : info->page_area.start.col);
+
+		val = sheet_cell_get_value 
+			(ref.a.sheet ? ref.a.sheet : (Sheet *)(info->sheet), 
+			 ref.a.col, ref.a.row);
+		if (val != NULL) {
+			char const *value;
+			value = value_peek_string (val);
+			g_string_append (target, value);
+		}
+	}
+	else {
+		if (use_repeating)
+			g_string_append (target, "[");
+		g_string_append (target, args);
+		if (use_repeating)
+			g_string_append (target, "]");
+	}
+}
+
 static void
 render_tab (GString *target, HFRenderInfo *info, char const *args)
 {
@@ -523,6 +574,7 @@ static struct {
 	{ N_("time"),  render_time  , NULL},
 	{ N_("file"),  render_file  , NULL},
 	{ N_("path"),  render_path  , NULL},
+	{ N_("cell"),  render_cell  , NULL},
 	{ NULL },
 };
 
@@ -598,6 +650,9 @@ hf_render_info_new (void)
 	hfi = g_new0 (HFRenderInfo, 1);
 	hfi->date_time = value_new_float (
 		datetime_timet_to_serial_raw (time (NULL), NULL));
+	range_init_full_sheet (&hfi->page_area);
+	hfi->top_repeating.col = 0;
+	hfi->top_repeating.row = 0;
 
 	return hfi;
 }
@@ -616,18 +671,105 @@ pdf_write_workbook (GOFileSaver const *fs, IOContext *context,
 		    gconstpointer wbv_, GsfOutput *output)
 {
 	WorkbookView const *wbv = wbv_;
+	Workbook const *wb = wb_view_get_workbook (wbv);
+	GPtrArray *sheets = g_object_get_data (G_OBJECT (wb), "pdf-sheets");
+
+	if (sheets) {
+		int i;
+
+		for (i = 0; i < workbook_sheet_count (wb); i++) {
+			Sheet *sheet = workbook_sheet_by_index (wb, i);
+			sheet->print_info->do_not_print = TRUE;
+		}
+		for (i = 0; i < (int)sheets->len; i++) {
+			Sheet *sheet = g_ptr_array_index (sheets, i);
+			sheet->print_info->do_not_print = FALSE;
+		}
+	}
+
 	gnm_print_sheet (NULL, wb_view_cur_sheet (wbv), FALSE,
 			 PRINT_ALL_SHEETS, output);
 }
 
+static void
+cb_free_sheets (GPtrArray *a)
+{
+	g_ptr_array_free (a, TRUE);
+}
+
+static gboolean
+cb_set_pdf_option (const char *key, const char *value,
+		   GError **err, gpointer user)
+{
+	Workbook *wb = user;
+
+	if (strcmp (key, "sheet") == 0) {
+		Sheet *sheet = workbook_sheet_by_name (wb, value);
+		GPtrArray *sheets;
+
+		if (!sheet) {
+			*err = g_error_new (go_error_invalid (), 0,
+					    _("There is no such sheet"));
+			return TRUE;
+		}
+
+		sheets = g_object_get_data (G_OBJECT (wb), "pdf-sheets");
+		if (!sheets) {
+			sheets = g_ptr_array_new ();
+			g_object_set_data_full (G_OBJECT (wb),
+						"pdf-sheets", sheets,
+						(GDestroyNotify)cb_free_sheets);
+		}
+		g_ptr_array_add (sheets, sheet);
+
+		return FALSE;
+	}
+
+	if (strcmp (key, "paper") == 0) {
+		int i;
+
+		for (i = 0; i < workbook_sheet_count (wb); i++) {
+			Sheet *sheet = workbook_sheet_by_index (wb, i);
+			if (print_info_set_paper (sheet->print_info, value)) {
+				*err = g_error_new (go_error_invalid (), 0,
+						    _("Unknown paper size"));
+
+				return TRUE;
+			}
+		}
+		return FALSE;
+	}
+
+	if (err)
+		*err = g_error_new (go_error_invalid (), 0,
+				    _("Invalid option for pdf exporter"));
+
+	return TRUE;
+}
+
+static gboolean
+pdf_set_export_options (GOFileSaver *fs,
+			GODoc *doc,
+			const char *options,
+			GError **err,
+			gpointer user)
+{
+	return go_parse_key_value (options, err, cb_set_pdf_option, doc);
+}
+
 void
 print_init (void)
 {
 	/* Install a pdf saver.  */
-	go_file_saver_register (go_file_saver_new (
-		"Gnumeric_pdf:pdf_assistant", "pdf",
+	GOFileSaver *saver = go_file_saver_new (
+		PDF_SAVER_ID, "pdf",
 		_("PDF export"),
-		FILE_FL_WRITE_ONLY, pdf_write_workbook));
+		FILE_FL_WRITE_ONLY, pdf_write_workbook);
+	g_signal_connect (G_OBJECT (saver), "set-export-options",
+			  G_CALLBACK (pdf_set_export_options),
+			  NULL);
+	go_file_saver_register (saver);
+	g_object_unref (saver);
 
 	load_formats ();
 }
@@ -635,6 +777,8 @@ print_init (void)
 void
 print_shutdown (void)
 {
+	go_file_saver_unregister (go_file_saver_for_id (PDF_SAVER_ID));
+
 	save_formats ();
 	destroy_formats ();
 }
@@ -773,12 +917,26 @@ print_info_set_margins (PrintInformation *pi,
 						 right, GTK_UNIT_POINTS);
 }
 
-void
-page_setup_set_paper        (GtkPageSetup *page_setup, char const *paper)
+
+static void
+paper_log_func (const gchar   *log_domain,
+		GLogLevelFlags log_level,
+		const gchar   *message,
+		gpointer       user_data)
+{
+	int *pwarn = user_data;
+
+	if (log_level & G_LOG_LEVEL_WARNING)
+		*pwarn = 1;
+}
+
+gboolean
+page_setup_set_paper (GtkPageSetup *page_setup, char const *paper)
 {
 	GtkPaperSize* gtk_paper;
+	int bad_paper = 0;
 
-	g_return_if_fail (page_setup != NULL);
+	g_return_val_if_fail (page_setup != NULL, TRUE);
 
 /* We are now using the standard paper names given by PWG 5101.1-2002 */
 /* We are trying to map some old gnome-print paper names.                  */
@@ -793,32 +951,51 @@ page_setup_set_paper        (GtkPageSetup *page_setup, char const *paper)
  "B5" -> GTK_PAPER_NAME_B5
  *  */
 
-	if (g_ascii_strncasecmp ("A4", paper, 2) == 0)
+	if (g_ascii_strcasecmp ("A4", paper) == 0)
 		paper = GTK_PAPER_NAME_A4;
-	if (g_ascii_strncasecmp ("A3", paper, 2) == 0)
+	else if (g_ascii_strcasecmp ("A3", paper) == 0)
 	        paper = GTK_PAPER_NAME_A3;
-	if (g_ascii_strncasecmp ("A5", paper, 2) == 0)
+	else if (g_ascii_strcasecmp ("A5", paper) == 0)
 		paper = GTK_PAPER_NAME_A5;
-	if (g_ascii_strncasecmp ("B5", paper, 2) == 0)
+	else if (g_ascii_strcasecmp ("B5", paper) == 0)
 		paper = GTK_PAPER_NAME_B5;
-	if (g_ascii_strncasecmp ("USLetter", paper, 8) == 0)
+	else if (g_ascii_strcasecmp ("USLetter", paper) == 0 ||
+		 g_ascii_strcasecmp ("US-Letter", paper) == 0 ||
+		 g_ascii_strcasecmp ("Letter", paper) == 0)
 		paper = GTK_PAPER_NAME_LETTER;
-	if (g_ascii_strncasecmp ("USLegal", paper, 7) == 0)
+	else if (g_ascii_strcasecmp ("USLegal", paper) == 0)
 		paper = GTK_PAPER_NAME_LEGAL;
-	if (g_ascii_strncasecmp ("Executive", paper, 9) == 0)
+	else if (g_ascii_strncasecmp ("Executive", paper, 9) == 0)
 		paper = GTK_PAPER_NAME_EXECUTIVE;
 
-	gtk_paper = gtk_paper_size_new (paper);
-	gtk_page_setup_set_paper_size (page_setup, gtk_paper);
-	gtk_paper_size_free (gtk_paper);
+	/* Hack: gtk_paper_size_new warns on bad paper, so shut it up.  */
+	/* http://bugzilla.gnome.org/show_bug.cgi?id=493880 */
+	{
+		const char *domain = "Gtk";
+		guint handler = g_log_set_handler (domain, G_LOG_LEVEL_WARNING,
+						   paper_log_func, &bad_paper);
+
+		gtk_paper = gtk_paper_size_new (paper);
+		g_log_remove_handler (domain, handler);
+		if (!gtk_paper)
+			bad_paper = 1;
+	}
+
+	if (!bad_paper)
+		gtk_page_setup_set_paper_size (page_setup, gtk_paper);
+	if (gtk_paper)
+		gtk_paper_size_free (gtk_paper);
+
+	return bad_paper;
 }
 
-void
+gboolean
 print_info_set_paper (PrintInformation *pi, char const *paper)
 {
-	g_return_if_fail (pi != NULL);
+	g_return_val_if_fail (pi != NULL, TRUE);
+
 	print_info_load_defaults (pi);
-	page_setup_set_paper (pi->page_setup, paper);
+	return page_setup_set_paper (pi->page_setup, paper);
 }
 
 char *
