@@ -358,14 +358,9 @@ sv_make_cell_visible (SheetView *sv, int col, int row,
 void
 sv_redraw_range	(SheetView *sv, GnmRange const *r)
 {
-	GnmRange tmp = *r;
-
 	g_return_if_fail (IS_SHEET_VIEW (sv));
-	if (sv->sheet == NULL) /* beware initialization */
-		return;
-	sheet_range_bounding_box (sv->sheet, &tmp);
-	SHEET_VIEW_FOREACH_CONTROL (sv, control,
-		sc_redraw_range (control, &tmp););
+
+	SHEET_VIEW_FOREACH_CONTROL (sv, sc, sc_redraw_range (sc, r););
 }
 
 void
@@ -402,8 +397,8 @@ sv_selection_cut (SheetView *sv, WorkbookControl *wbc)
 	 * doing here.  'move' would be a better
 	 * approximation.  The key portion of this process is that
 	 * the range being moved has all
-	 * 	- references to it adjusted to the new site.
-	 * 	- relative references from it adjusted.
+	 *	- references to it adjusted to the new site.
+	 *	- relative references from it adjusted.
 	 *
 	 * NOTE : This command DOES NOT MOVE ANYTHING !
 	 *        We only store the src, paste does the move.
