@@ -199,7 +199,7 @@ wbcg_edit_finish (WBCGtk *wbcg, WBCEditResult result,
 				if (reedit == VALIDATION_STATUS_INVALID_EDIT)
 					return FALSE;
 				/* restore focus to sheet , or we'll leave edit
-				 * mode only to jump right back in in the new
+				 * mode only to jump right back in the new
 				 * cell because it looks like someone just
 				 * focused on the edit line (eg hit F2) */
 				wbcg_focus_cur_scg (wbcg);
@@ -882,12 +882,19 @@ wbcg_edit_start (WBCGtk *wbcg,
 			}
 
 			case GO_FORMAT_DATE: {
+				const char *ftxt;
 				GString *fstr;
 				GOFormat *new_fmt;
-				gboolean mbd = gnm_format_month_before_day
+				int mbd = gnm_format_month_before_day
 					(fmt, cell->value);
 
-				fstr = g_string_new (mbd ? "m/d/yyyy" : "d/m/yyyy");
+				switch (mbd) {
+				case 0: ftxt = "d/m/yyyy"; break;
+				default:
+				case 1: ftxt = "m/d/yyyy"; break;
+				case 2: ftxt = "yyyy-m-d"; break;
+				}
+				fstr = g_string_new (ftxt);
 
 				if (!close_to_int (f, 1e-6 / (24 * 60 * 60))) {
 					g_string_append_c (fstr, ' ');
@@ -948,7 +955,7 @@ wbcg_edit_start (WBCGtk *wbcg,
 	gnm_expr_entry_set_scg (wbcg->edit_line.entry, scg);
 	gnm_expr_entry_set_flags (wbcg->edit_line.entry,
 		GNM_EE_SHEET_OPTIONAL | GNM_EE_FORMULA_ONLY,
-		GNM_EE_SINGLE_RANGE | GNM_EE_SHEET_OPTIONAL | GNM_EE_FORMULA_ONLY);
+		GNM_EE_SINGLE_RANGE | GNM_EE_SHEET_OPTIONAL | GNM_EE_FORMULA_ONLY | GNM_EE_FORCE_REL_REF | GNM_EE_FORCE_ABS_REF);
 	scg_edit_start (scg);
 
 	/* Redraw the cell contents in case there was a span */
