@@ -196,51 +196,93 @@ wb_control_cur_sheet_view (WorkbookControl const *wbc)
 	return wb_view_cur_sheet_view (wbc->wb_view);
 }
 
+static void
+wb_create_name (WorkbookControl *wbc, char const *text, GnmParsePos *pp)
+{
+	GnmRange const *r;
+	GnmCellRef a, b;
+	GnmExpr const *target_range;
+	
+	r = selection_first_range (wb_control_cur_sheet_view (wbc),
+		                   GO_CMD_CONTEXT (wbc), _("Define Name"));
+	if (r != NULL) {
+		a.sheet = b.sheet = wb_control_cur_sheet (wbc);
+		a.col = r->start.col;
+		a.row = r->start.row;
+		b.col = r->end.col;
+		b.row = r->end.row;
+		a.col_relative = a.row_relative = b.col_relative = b.row_relative = FALSE;
+		pp->sheet = NULL; /* make it a global name */
+		if (gnm_cellref_equal (&a, &b))
+			target_range = gnm_expr_new_cellref (&a);
+		else
+			target_range = gnm_expr_new_constant (
+				value_new_cellrange_unsafe (&a, &b));
+		cmd_define_name (wbc, text, pp, gnm_expr_top_new (target_range), NULL);
+	}
+}
+
+/*
+ * Select the given range and make the it visible.
+ */
+static gboolean
+wb_control_jump (WorkbookControl *wbc, Sheet *sheet, const GnmRangeRef *r)
+{
+	SheetView *sv;
+	GnmCellPos tmp;
+
+	if (r->a.sheet)
+		sheet = r->a.sheet;
+
+	if (!sheet_is_visible (sheet)) {
+		go_cmd_context_error_invalid
+			(GO_CMD_CONTEXT (wbc),
+			 _("Cannot jump to an invisible sheet"),
+			 sheet->name_unquoted);
+		return FALSE;
+	}
+
+	sv = sheet_get_view (sheet, wb_control_view (wbc));
+
+	tmp.col = r->a.col;
+	tmp.row = r->a.row;
+	sv_selection_set (sv, &tmp, r->a.col, r->a.row, r->b.col, r->b.row);
+	sv_make_cell_visible (sv, r->b.col, r->b.row, FALSE);
+	sv_make_cell_visible (sv, r->a.col, r->a.row, FALSE);
+	sv_update (sv);
+	if (wb_control_cur_sheet (wbc) != sheet)
+		wb_view_sheet_focus (wbc->wb_view, sheet);
+
+	return TRUE;
+}
+
+/*
+ * This is called when something is entered in the location entry.
+ * We either go there (if the text refers to a cell by address or
+ * name), or we try to define a name for the selection.
+ */
 gboolean
 wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 {
-	GnmRangeRef r;
-	GnmCellPos tmp;
-	Sheet *sheet  = wb_control_cur_sheet (wbc);
-	SheetView *sv;
+	Sheet *sheet = wb_control_cur_sheet (wbc);
+	GnmParsePos pp;
 	GnmValue *target;
-	const GnmRange *first_range;
-	GnmEvalPos ep;
+	gboolean res;
 
 	if (text == NULL || *text == '\0')
 		return FALSE;
 
-	/* not an address, is it a name ? */
-	target = value_new_cellrange_str (sheet, text);
+	parse_pos_init_editpos (&pp, wb_control_cur_sheet_view (wbc));
+	target = value_new_cellrange_parsepos_str (&pp, text);
 	if (target == NULL) {
+		/* Not an address; is it a name? */
 		GnmParsePos pp;
 		GnmNamedExpr *nexpr = expr_name_lookup (
 			parse_pos_init_sheet (&pp, sheet), text);
 
 		/* If no name, or just a placeholder exists create a name */
 		if (nexpr == NULL || expr_name_is_placeholder (nexpr)) {
-			GnmRange const *r = selection_first_range (
-				wb_control_cur_sheet_view (wbc),
-				GO_CMD_CONTEXT (wbc),
-				_("Define Name"));
-			if (r != NULL) {
-				GnmCellRef a, b;
-				GnmExpr const *target_range;
-
-				a.sheet = b.sheet = sheet;
-				a.col = r->start.col;
-				a.row = r->start.row;
-				b.col = r->end.col;
-				b.row = r->end.row;
-				a.col_relative = a.row_relative = b.col_relative = b.row_relative = FALSE;
-				pp.sheet = NULL; /* make it a global name */
-				if (gnm_cellref_equal (&a, &b))
-					target_range = gnm_expr_new_cellref (&a);
-				else
-					target_range = gnm_expr_new_constant (
-						value_new_cellrange_unsafe (&a, &b));
-				cmd_define_name (wbc, text, &pp, gnm_expr_top_new (target_range), NULL);
-			}
+			wb_create_name (wbc, text, &pp);
 			return FALSE;
 		} else {
 			target = gnm_expr_top_get_range (nexpr->texpr);
@@ -252,28 +294,9 @@ wb_control_parse_and_jump (WorkbookControl *wbc, char const *text)
 		}
 	}
 
-	sv = sheet_get_view (sheet, wb_control_view (wbc));
-	first_range = selection_first_range (sv, NULL, NULL);
-	eval_pos_init_pos (&ep, sheet, &first_range->start);
-
-	gnm_cellref_make_abs (&r.a, &target->v_range.cell.a, &ep);
-	gnm_cellref_make_abs (&r.b, &target->v_range.cell.b, &ep);
-
-	if (r.a.sheet) {
-		sheet = r.a.sheet;
-		sv = sheet_get_view (sheet, wb_control_view (wbc));
-	}
-
-	tmp.col = r.a.col;
-	tmp.row = r.a.row;
-	sv_selection_set (sv, &tmp, r.a.col, r.a.row, r.b.col, r.b.row);
-	sv_make_cell_visible (sv, r.b.col, r.b.row, FALSE);
-	sv_make_cell_visible (sv, r.a.col, r.a.row, FALSE);
-	sv_update (sv);
-	if (wb_control_cur_sheet (wbc) != sheet)
-		wb_view_sheet_focus (wbc->wb_view, sheet);
+	res = wb_control_jump (wbc, sheet, &target->v_range.cell);
 	value_release (target);
-	return TRUE;
+	return res;
 }
 
 static void
@@ -395,7 +418,7 @@ wb_control_init_state (WorkbookControl *wbc)
 	/* Setup the undo/redo combos */
 	command_setup_combos (wbc);
 
-	/* Add views all all existing sheets */
+	/* Add views for all existing sheets */
 	wbv = wb_control_view (wbc);
 	sheets = workbook_sheets (wb_control_get_workbook (wbc));
 	for (ptr = sheets; ptr != NULL ; ptr = ptr->next) {
