@@ -647,6 +647,11 @@ xml_read_print_info (XmlParseContext *ctxt, xmlNodePtr tree)
 		xml_node_get_int  (child, "value",  &b);
 		pi->print_titles          = (b == 1);
 	}
+	if ((child = e_xml_get_child_by_name (tree, CC2XML ("do_not_print")))) {
+		xml_node_get_int  (child, "value",    &b);
+		pi->do_not_print  = (b == 1);
+	}
+
 
 	xml_read_print_repeat_range (ctxt, tree, "repeat_top",
 				     &pi->repeat_top);
@@ -1516,7 +1521,7 @@ xml_read_solver (XmlParseContext *ctxt, xmlNodePtr tree)
 				c->type = SolverLE;
 				break;
 			}
-#ifdef ENABLE_SOLVER
+#ifdef GNM_ENABLE_SOLVER
 			c->str = write_constraint_str (c->lhs.col, c->lhs.row,
 						       c->rhs.col, c->rhs.row,
 						       c->type, c->cols, c->rows);
